### Hit the spacebar to start

This example has sourcemap support for Google Chrome. Press F12, click the sources tab and then click somewhere near the end of pong.js to try.
You have to click near the end since 90% of the JS code is the large fabric.js library. Fabric.js is used here just as an example, this simple demo could have been programmed directly on top of the HTML5 canvas.
A
Z
K
M
Space
Enter